pub fn find_dependents(name: &str, conn: &DbConnection) -> Result<Vec<String>>Expand description
Find installed packages that depend on the named package.
Dependency entries may include a version suffix in the form name@version.
Only the package name is used for matching so the dependency check remains
stable even if the dependency recorded a specific version.